@@ -8,8 +8,7 @@ from ._api.iconkeys import Snoo
 from typing import Dict, List, Optional, Callable
 from ._utils.frame_model import FrameType, FrameModel
 from ._events import Events
-from ._utils._exceptions import HookException
-
+from ._utils.exceptions import HookException
 
 _hook = Callable[[FrameModel], Optional[bool]]
 
@@ -171,6 +170,7 @@ class ChatBot(Tools):
 
     def close(self) -> None:
         self.__WebSocketClient.ws.close()
+        self.__is_running = True
 
     def leave_chat(self, channel_url: str) -> None:
         super().leave_chat(channel_url)
